Increase 2ms to 5ms to reduce flake.

Bug: http://b/121156651
Test: ran tests
Change-Id: Ief699cacf920b144bf66821cf0ac73930fae9274
diff --git a/tests/sys_time_test.cpp b/tests/sys_time_test.cpp
index 16187eb..d033364 100644
--- a/tests/sys_time_test.cpp
+++ b/tests/sys_time_test.cpp
@@ -147,7 +147,7 @@
     tv2.tv_usec += 1000000;
   }
 
   // Should be less than (a very generous, to try to avoid flakiness) 2ms (2000us).
   ASSERT_EQ(0, tv2.tv_sec);
-  ASSERT_LT(tv2.tv_usec, 2000);
+  ASSERT_LT(tv2.tv_usec, 5000);
 }
@@ -147,7 +147,7 @@
   }
 
-  // Should be less than (a very generous, to try to avoid flakiness) 2ms (2000us).
+  // Should be less than (a very generous, to try to avoid flakiness) 5ms (5000us).
   ASSERT_EQ(0, tv2.tv_sec);